<map version="0.8.0">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node BACKGROUND_COLOR="#ffcc00" CREATED="1150481365390" ID="Freemind_Link_1699128560" MODIFIED="1204995863985" TEXT="Stellarium interface">
<font BOLD="true" NAME="SansSerif" SIZE="17"/>
<node BACKGROUND_COLOR="#ffffff" CREATED="1150488471312" HGAP="61" ID="Freemind_Link_85112228" MODIFIED="1202859653181" POSITION="left" TEXT="horizontal button bar" VSHIFT="75">
<cloud COLOR="#d5f2ff"/>
<node CREATED="1150488551218" ID="Freemind_Link_235163759" MODIFIED="1150488554968" TEXT="constellation drawings"/>
<node CREATED="1150488686531" ID="Freemind_Link_924518447" MODIFIED="1150488690234" TEXT="constellation names"/>
<node CREATED="1150488555406" ID="Freemind_Link_461803795" MODIFIED="1150488558500" TEXT="constellation art"/>
<node CREATED="1150488559281" ID="Freemind_Link_1562857837" MODIFIED="1150488565390" TEXT="AZ grid"/>
<node CREATED="1150488565640" ID="Freemind_Link_815125769" MODIFIED="1150488568000" TEXT="EQ grid"/>
<node CREATED="1150488702531" ID="Freemind_Link_1545732922" MODIFIED="1150488705000" TEXT="atmosphere"/>
<node CREATED="1150488705625" ID="Freemind_Link_1305962609" MODIFIED="1150488714312" TEXT="enable landscape"/>
<node CREATED="1150489609734" ID="Freemind_Link_1139344325" MODIFIED="1150489613046" TEXT="cardinal points"/>
<node CREATED="1150488568265" ID="Freemind_Link_429495669" MODIFIED="1150488573343" TEXT="nebula labels"/>
<node CREATED="1150488809125" ID="Freemind_Link_947629042" MODIFIED="1150488817656" TEXT="EQ/AZ viewing"/>
<node CREATED="1150488818890" ID="Freemind_Link_27867374" MODIFIED="1150488824015" TEXT="center/track"/>
<node CREATED="1150488968140" ID="Freemind_Link_842181300" MODIFIED="1150488970875" TEXT="night mode"/>
<node CREATED="1194809340484" FOLDED="true" HGAP="28" ID="Freemind_Link_223553493" MODIFIED="1194809359984" TEXT="simple time control" VSHIFT="24">
<node CREATED="1150485774203" ID="Freemind_Link_1841849514" MODIFIED="1150485776296" TEXT="forward"/>
<node CREATED="1150485778390" ID="Freemind_Link_208918205" MODIFIED="1150485780750" TEXT="stop"/>
<node CREATED="1201450412343" ID="Freemind_Link_1270992428" MODIFIED="1201450416328" TEXT="now"/>
<node CREATED="1150485789062" ID="Freemind_Link_1646520631" MODIFIED="1150485790562" TEXT="play"/>
<node CREATED="1150485781734" ID="Freemind_Link_335985900" MODIFIED="1150485784109" TEXT="backward"/>
</node>
<node CREATED="1194809292000" ID="Freemind_Link_542988457" MODIFIED="1194809362062" TEXT="sliders" VSHIFT="22">
<node CREATED="1194809298843" ID="Freemind_Link_1783573352" MODIFIED="1194809302140" TEXT="labels"/>
<node CREATED="1194809303125" ID="Freemind_Link_950470124" MODIFIED="1194809307046" TEXT="stars"/>
<node CREATED="1194809317359" ID="Freemind_Link_1429085061" MODIFIED="1194809321859" TEXT="zoom"/>
</node>
<node CREATED="1150488979531" ID="Freemind_Link_1541587548" MODIFIED="1194809366375" TEXT="exit" VSHIFT="25"/>
</node>
<node CREATED="1150490250406" HGAP="32" ID="Freemind_Link_1827100874" MODIFIED="1202859687380" POSITION="right" TEXT="Qt windows" VSHIFT="-145">
<cloud COLOR="#ffffff"/>
<font ITALIC="true" NAME="SansSerif" SIZE="12"/>
<node CREATED="1202853442535" HGAP="39" ID="Freemind_Link_1626845154" MODIFIED="1202858037954" TEXT="time &amp; location window" VSHIFT="-5">
<cloud/>
<node CREATED="1150485851515" HGAP="47" ID="Freemind_Link_1156755185" MODIFIED="1202858924464" TEXT="time" VSHIFT="-16">
<cloud/>
<font NAME="SansSerif" SIZE="11"/>
<node CREATED="1150485871562" HGAP="33" ID="Freemind_Link_283361912" MODIFIED="1190575227875" TEXT="time display" VSHIFT="18"/>
<node CREATED="1150485526968" HGAP="42" ID="Freemind_Link_1151596428" MODIFIED="1190575230171" TEXT="time zone" VSHIFT="-22"/>
</node>
<node CREATED="1150481481078" HGAP="46" ID="Freemind_Link_353849393" MODIFIED="1202858926519" TEXT="location" VSHIFT="-21">
<cloud/>
<node CREATED="1150484626890" FOLDED="true" ID="Freemind_Link_1333646115" MODIFIED="1150490709078" TEXT="coordinates input">
<node CREATED="1150485451546" ID="Freemind_Link_566486949" MODIFIED="1150485464343" TEXT="latitude"/>
<node CREATED="1150485455093" ID="Freemind_Link_415581298" MODIFIED="1150485457734" TEXT="longitude"/>
<node CREATED="1150485458203" ID="Freemind_Link_605034405" MODIFIED="1150485460859" TEXT="altitude"/>
</node>
<node CREATED="1150484573656" ID="Freemind_Link_604019317" MODIFIED="1202858254670" TEXT="observatory name"/>
<node CREATED="1150484592875" ID="Freemind_Link_417371986" MODIFIED="1150485706109" TEXT="zoomable world/planet map"/>
<node CREATED="1150485683359" ID="Freemind_Link_116043811" MODIFIED="1150486252812" TEXT="planet"/>
<node CREATED="1150484578328" ID="Freemind_Link_305506358" MODIFIED="1150484581828" TEXT="list of saved locations"/>
<node CREATED="1150484633031" ID="Freemind_Link_1088452907" MODIFIED="1150490567937" TEXT="GPS coordinates"/>
<node CREATED="1202858216279" ID="Freemind_Link_1050419288" MODIFIED="1202858247904" TEXT="set associated landscape"/>
</node>
</node>
<node CREATED="1190572882234" HGAP="155" ID="Freemind_Link_1436502094" MODIFIED="1202858042354" TEXT="view window" VSHIFT="-20">
<cloud/>
<node CREATED="1206629575095" ID="Freemind_Link_1930286845" MODIFIED="1206629578795" TEXT="Sky">
<node CREATED="1150484928125" FOLDED="true" ID="Freemind_Link_1116728323" MODIFIED="1150540924265" TEXT="stars" VSHIFT="-4">
<cloud COLOR="#ccffcc"/>
<node CREATED="1150488383593" ID="Freemind_Link_1344309685" MODIFIED="1150488403687" TEXT="enable twinkle">
<node CREATED="1150482541843" ID="Freemind_Link_1437652228" MODIFIED="1150482545015" TEXT="twinkle amount"/>
</node>
<node CREATED="1150482532093" ID="Freemind_Link_1450257604" MODIFIED="1150482533406" TEXT="scale"/>
<node CREATED="1150482562609" ID="Freemind_Link_1676379448" MODIFIED="1150482572218" TEXT="point stars"/>
<node CREATED="1150482533734" ID="Freemind_Link_1578230580" MODIFIED="1150482539734" TEXT="magnitude scale"/>
<node CREATED="1150484929968" ID="Freemind_Link_801385891" MODIFIED="1150484932203" TEXT="star names">
<node CREATED="1150482546750" ID="Freemind_Link_1514582349" MODIFIED="1150482558500" TEXT="max. magnitude named"/>
</node>
</node>
<node CREATED="1150485024046" FOLDED="true" ID="Freemind_Link_1702272134" MODIFIED="1150541094546" TEXT="solar system">
<cloud COLOR="#ccffcc"/>
<node CREATED="1150484932828" ID="Freemind_Link_1433914814" MODIFIED="1202855087417" TEXT="show planets"/>
<node CREATED="1150484943796" ID="Freemind_Link_1227769331" MODIFIED="1202855111477" TEXT="show planet hints" VSHIFT="3"/>
<node CREATED="1150484951781" ID="Freemind_Link_431989207" MODIFIED="1202855090890" TEXT="show planet orbits"/>
<node CREATED="1150483899125" ID="Freemind_Link_1539800392" MODIFIED="1150483913406" TEXT="moon scale"/>
<node CREATED="1150484960000" ID="Freemind_Link_21712835" MODIFIED="1150484970062" TEXT="enable light travel time"/>
</node>
<node CREATED="1150485017718" FOLDED="true" HGAP="21" ID="Freemind_Link_1673297843" MODIFIED="1202857896325" TEXT="deep sky" VSHIFT="4">
<cloud COLOR="#ccffcc"/>
<node CREATED="1150485041796" ID="Freemind_Link_355404093" MODIFIED="1150485046750" TEXT="show nebula"/>
<node CREATED="1150485047015" ID="Freemind_Link_580424303" MODIFIED="1150485050703" TEXT="show nebula names">
<node CREATED="1150485172890" ID="Freemind_Link_852275024" MODIFIED="1150485180890" TEXT="long/short names"/>
</node>
<node CREATED="1150485245812" ID="Freemind_Link_668047753" MODIFIED="1150485260687" TEXT="flag bright nebula"/>
<node CREATED="1150485253250" ID="Freemind_Link_1690889674" MODIFIED="1150485257421" TEXT="flag ngc nebula"/>
<node CREATED="1150485126843" ID="Freemind_Link_1228085620" MODIFIED="1202855866764" TEXT="show milky way">
<node CREATED="1150485140656" ID="Freemind_Link_1588031745" MODIFIED="1150485144812" TEXT="milky way intensity"/>
</node>
</node>
<node CREATED="1150488730000" ID="Freemind_Link_1245295491" MODIFIED="1150488733531" TEXT="shooting stars">
<node CREATED="1150489629390" ID="Freemind_Link_1562641144" MODIFIED="1150489630984" TEXT="enable"/>
<node CREATED="1150489631375" ID="Freemind_Link_411708657" MODIFIED="1150489640687" TEXT="meteor rate"/>
</node>
</node>
<node CREATED="1150484119859" FOLDED="true" ID="Freemind_Link_1086145808" MODIFIED="1202851965421" TEXT="markings">
<cloud COLOR="#ccffcc"/>
<node CREATED="1150483889062" ID="Freemind_Link_1168131594" MODIFIED="1150483893031" TEXT="meridian line"/>
<node CREATED="1150483883406" ID="Freemind_Link_955167158" MODIFIED="1150483888796" TEXT="ecliptic line"/>
<node CREATED="1150483879265" ID="Freemind_Link_1555166638" MODIFIED="1150483883125" TEXT="equator line"/>
<node CREATED="1150483846906" ID="Freemind_Link_1209995490" MODIFIED="1150483851734" TEXT="equatorial grid"/>
<node CREATED="1150483842125" ID="Freemind_Link_571277997" MODIFIED="1150483846656" TEXT="azimutal grid"/>
<node CREATED="1150483893484" ID="Freemind_Link_51739494" MODIFIED="1150483898687" TEXT="cardinal points"/>
<node CREATED="1150484004500" HGAP="30" ID="Freemind_Link_926084442" MODIFIED="1150540930046" TEXT="constellations">
<cloud COLOR="#ccffcc"/>
<node CREATED="1150483805718" ID="Freemind_Link_1860280869" MODIFIED="1150483814437" TEXT="constellation names"/>
<node CREATED="1150483792718" ID="Freemind_Link_609087940" MODIFIED="1150483805234" TEXT="constellation line drawings"/>
<node CREATED="1150483815437" ID="Freemind_Link_1370804499" MODIFIED="1150483817640" TEXT="constellation art">
<node CREATED="1150483929546" ID="Freemind_Link_1841455978" MODIFIED="1150483934625" TEXT="intensity"/>
<node CREATED="1150483939203" ID="Freemind_Link_1861737052" MODIFIED="1150483942843" TEXT="fade duration"/>
</node>
<node CREATED="1150483817921" ID="Freemind_Link_303363876" MODIFIED="1150483827000" TEXT="constellation boundaries"/>
<node CREATED="1150483827562" ID="Freemind_Link_1131717595" MODIFIED="1190554263687" TEXT="isolate selected constellation" VSHIFT="5"/>
</node>
<node CREATED="1202856723196" ID="Freemind_Link_489307642" MODIFIED="1202857595536" TEXT="projection">
<cloud/>
<node CREATED="1150481598046" ID="Freemind_Link_1388756462" MODIFIED="1202856778680" STYLE="fork" TEXT="projection type">
<edge STYLE="bezier"/>
<node CREATED="1150482919031" ID="Freemind_Link_1137595203" MODIFIED="1150482941109" TEXT="perspective"/>
<node CREATED="1150482923718" ID="Freemind_Link_721326200" MODIFIED="1150482926734" TEXT="fisheye"/>
<node CREATED="1150482927515" ID="Freemind_Link_259992491" MODIFIED="1150482930609" TEXT="stereographic"/>
<node CREATED="1202858529969" ID="Freemind_Link_693538494" MODIFIED="1202858534218" TEXT="cylindric"/>
</node>
</node>
</node>
<node CREATED="1150481379562" HGAP="35" ID="_" MODIFIED="1202857795932" TEXT="starlore window" VSHIFT="1">
<cloud/>
<node CREATED="1150488243046" ID="Freemind_Link_943294789" MODIFIED="1202852101192" TEXT="sky cultures list">
<node CREATED="1150488248984" ID="Freemind_Link_200307796" MODIFIED="1150488251406" TEXT="Korean"/>
<node CREATED="1150488251906" ID="Freemind_Link_256752669" MODIFIED="1150488253531" TEXT="Western"/>
<node CREATED="1150488253796" ID="Freemind_Link_1798420241" MODIFIED="1150488255609" TEXT="Chinese"/>
<node CREATED="1150488255906" ID="Freemind_Link_1503257861" MODIFIED="1150488259796" TEXT="Polynesian"/>
<node CREATED="1150488260078" ID="Freemind_Link_231237120" MODIFIED="1150488263046" TEXT="Navajo"/>
<node CREATED="1150488263312" ID="Freemind_Link_1760603957" MODIFIED="1150488266359" TEXT="Lakota"/>
<node CREATED="1150488266625" ID="Freemind_Link_340277813" MODIFIED="1150488268796" TEXT="Inuit"/>
<node CREATED="1150488269078" ID="Freemind_Link_1441390464" MODIFIED="1150488270843" TEXT="Pawnee"/>
</node>
<node CREATED="1202851863374" ID="Freemind_Link_503035999" MODIFIED="1202851865388" TEXT="show original sky language checkbox"/>
</node>
<node CREATED="1150481405156" ID="Freemind_Link_735770544" MODIFIED="1202858226105" TEXT="atmosphere/effects/phenomena" VSHIFT="13">
<cloud/>
<node CREATED="1150481472031" ID="Freemind_Link_226530346" MODIFIED="1202858663651" TEXT="landscape list" VSHIFT="-4"/>
<node CREATED="1150482383125" ID="Freemind_Link_545507947" MODIFIED="1150482385218" TEXT="fog"/>
<node CREATED="1150482395437" ID="Freemind_Link_997669099" MODIFIED="1150482398078" TEXT="atmosphere"/>
</node>
</node>
<node CREATED="1150489064906" FOLDED="true" HGAP="188" ID="Freemind_Link_1888895186" MODIFIED="1202857750511" TEXT="search window" VSHIFT="-43">
<cloud/>
<node CREATED="1150489115687" ID="Freemind_Link_1983620686" MODIFIED="1150489129796" TEXT="input field with suggestion as you type"/>
<node CREATED="1150489142734" ID="Freemind_Link_762164162" MODIFIED="1150489153390" TEXT="select type of object"/>
<node CREATED="1150489131843" ID="Freemind_Link_1461297131" MODIFIED="1150489140437" TEXT="go button"/>
</node>
<node CREATED="1150489181031" FOLDED="true" HGAP="189" ID="Freemind_Link_1583365933" MODIFIED="1202854650766" TEXT="help window" VSHIFT="-7">
<edge WIDTH="thin"/>
<cloud/>
<node CREATED="1150489198515" ID="Freemind_Link_1271611726" MODIFIED="1150490705156" TEXT="user&apos;s guide"/>
<node CREATED="1150489188375" ID="Freemind_Link_1351795014" MODIFIED="1150490705593" TEXT="keyboard shortcut cheat sheet"/>
<node CREATED="1186516235609" FOLDED="true" ID="Freemind_Link_1928950899" MODIFIED="1190576594062" TEXT="information">
<node CREATED="1150481822421" HGAP="22" ID="Freemind_Link_1957439995" MODIFIED="1150487530765" STYLE="fork" TEXT="GPL" VSHIFT="3">
<edge STYLE="bezier"/>
</node>
<node CREATED="1150487522843" ID="Freemind_Link_830683682" MODIFIED="1150487526359" TEXT="developers"/>
</node>
</node>
<node CREATED="1150487184171" FOLDED="true" HGAP="172" ID="Freemind_Link_1770455329" MODIFIED="1202858990007" TEXT="scripting window" VSHIFT="18">
<cloud/>
<node CREATED="1150487203906" HGAP="41" ID="Freemind_Link_346164931" MODIFIED="1150487827796" TEXT="load script" VSHIFT="-4"/>
<node CREATED="1150487223125" FOLDED="true" ID="Freemind_Link_1754743330" MODIFIED="1150487226093" TEXT="script control">
<node CREATED="1150487226984" ID="Freemind_Link_79508441" MODIFIED="1150487228468" TEXT="play"/>
<node CREATED="1150487229078" ID="Freemind_Link_774305186" MODIFIED="1150487230500" TEXT="pause"/>
<node CREATED="1150487231312" ID="Freemind_Link_452221818" MODIFIED="1150487232890" TEXT="record"/>
</node>
<node CREATED="1150481779343" ID="Freemind_Link_1778370636" MODIFIED="1150487178937" TEXT="show script input field on startup" VSHIFT="7"/>
<node CREATED="1150487103296" HGAP="24" ID="Freemind_Link_1363078472" MODIFIED="1150487118828" TEXT="allow scripting" VSHIFT="1"/>
</node>
<node CREATED="1150481547562" HGAP="55" ID="Freemind_Link_264271356" MODIFIED="1202859055033" TEXT="program options window" VSHIFT="18">
<cloud/>
<node CREATED="1150481656953" ID="Freemind_Link_159010116" MODIFIED="1202857218905" STYLE="fork" TEXT="program language">
<edge STYLE="bezier"/>
</node>
<node CREATED="1190574370625" HGAP="22" ID="Freemind_Link_1078531356" MODIFIED="1202857226761" TEXT="display" VSHIFT="-3">
<node CREATED="1150482849468" ID="Freemind_Link_493871412" MODIFIED="1150486301796" STYLE="fork" TEXT="frame rate limiter (max fps)">
<edge STYLE="bezier"/>
</node>
</node>
<node CREATED="1202857342628" ID="Freemind_Link_1429727652" MODIFIED="1202857361258" TEXT="initial parameters">
<node CREATED="1150487450203" ID="Freemind_Link_789803054" MODIFIED="1202857507206" TEXT="initial time" VSHIFT="-5">
<node CREATED="1150487477093" FOLDED="true" ID="Freemind_Link_398279288" MODIFIED="1202859413120" TEXT="start at preset sky time">
<node CREATED="1202859416560" ID="Freemind_Link_1783872930" MODIFIED="1202859428220" TEXT="preset time list"/>
</node>
<node CREATED="1150487486609" ID="Freemind_Link_819223140" MODIFIED="1202859402537" TEXT="start at actual time"/>
</node>
<node CREATED="1150482879968" ID="Freemind_Link_916761760" MODIFIED="1202857401172" TEXT="fullscreen/windowed" VSHIFT="4"/>
<node CREATED="1150481607687" ID="Freemind_Link_1629819804" MODIFIED="1202857466153" STYLE="fork" TEXT="screen size (if windowed)">
<edge STYLE="bezier"/>
<node CREATED="1150483072046" ID="Freemind_Link_1255273566" MODIFIED="1202859353415" TEXT="800x600">
<font ITALIC="true" NAME="SansSerif" SIZE="12"/>
</node>
<node CREATED="1202859354751" ID="Freemind_Link_1635974251" MODIFIED="1202859357357" TEXT="1024x768"/>
</node>
<node CREATED="1150486360531" ID="Freemind_Link_549731331" MODIFIED="1150486363640" TEXT="initial FOV"/>
<node CREATED="1150486382406" ID="Freemind_Link_791549614" MODIFIED="1190404933625" TEXT="initial viewing position"/>
<node CREATED="1150486367375" ID="Freemind_Link_1993592289" MODIFIED="1202859486221" TEXT="equatorial/altazimutal mount"/>
</node>
<node CREATED="1150486143437" ID="Freemind_Link_1372169593" MODIFIED="1202856883269" TEXT="controls">
<node CREATED="1150486164015" ID="Freemind_Link_221653643" MODIFIED="1150486167875" TEXT="enable manual zoom"/>
<node CREATED="1150486156640" ID="Freemind_Link_857252848" MODIFIED="1150486160421" TEXT="enable zoom keys"/>
<node CREATED="1150486202375" ID="Freemind_Link_296299319" MODIFIED="1202859253109" TEXT="enable zoom mouse"/>
<node CREATED="1150486211718" ID="Freemind_Link_389241171" MODIFIED="1150486213750" TEXT="zoom speed"/>
<node CREATED="1150486172343" ID="Freemind_Link_1331336485" MODIFIED="1150486176000" TEXT="enable move keys">
<node CREATED="1150486207296" ID="Freemind_Link_1737842553" MODIFIED="1150486209656" TEXT="move speed"/>
</node>
<node CREATED="1150486176312" ID="Freemind_Link_1042253785" MODIFIED="1150486184859" TEXT="enable move mouse"/>
<node CREATED="1150486193687" ID="Freemind_Link_1564522632" MODIFIED="1150486197187" TEXT="auto move duration"/>
<node CREATED="1152299527484" FOLDED="true" ID="Freemind_Link_814730673" MODIFIED="1202857237764" TEXT="key bindings">
<cloud/>
<node CREATED="1152299574781" ID="Freemind_Link_1890969118" MODIFIED="1152299594078" TEXT="keyboard control customization"/>
</node>
</node>
<node CREATED="1150481704359" ID="Freemind_Link_209787311" MODIFIED="1150484272140" STYLE="fork" TEXT="GUI options">
<edge STYLE="bezier"/>
<node CREATED="1150481734796" FOLDED="true" HGAP="26" ID="Freemind_Link_955501007" MODIFIED="1202857544033" TEXT="infobar" VSHIFT="111">
<node CREATED="1150486761015" HGAP="31" ID="Freemind_Link_661775236" MODIFIED="1150486775265" TEXT="show y/n" VSHIFT="5"/>
<node CREATED="1150481862828" FOLDED="true" ID="Freemind_Link_141463521" MODIFIED="1150481865265" TEXT="show date">
<node CREATED="1150485593656" ID="Freemind_Link_376413232" MODIFIED="1150485597703" TEXT="date display format"/>
</node>
<node CREATED="1150481868375" FOLDED="true" ID="Freemind_Link_251001999" MODIFIED="1150482215937" TEXT="show time">
<node CREATED="1150485629625" ID="Freemind_Link_74020032" MODIFIED="1150485633000" TEXT="time display format"/>
</node>
<node CREATED="1150481728500" ID="Freemind_Link_665547164" MODIFIED="1150481733718" TEXT="show app name"/>
<node CREATED="1150481714546" ID="Freemind_Link_1355225570" MODIFIED="1202856427872" TEXT="show fps"/>
</node>
<node CREATED="1150487058218" HGAP="23" ID="Freemind_Link_188807783" MODIFIED="1202857545833" TEXT="cursor timeout" VSHIFT="2"/>
<node CREATED="1204991277165" ID="Freemind_Link_1054591906" MODIFIED="1204991286083" TEXT="Selected Object Info"/>
<node CREATED="1202856248632" FOLDED="true" HGAP="28" ID="Freemind_Link_724701714" MODIFIED="1202857075177" TEXT="styles" VSHIFT="-129">
<node CREATED="1150482145468" FOLDED="true" HGAP="21" ID="Freemind_Link_960990631" MODIFIED="1150486281546" TEXT="night colors" VSHIFT="2">
<node CREATED="1150481968859" ID="Freemind_Link_1965474773" MODIFIED="1150482013546" TEXT="base color"/>
<node CREATED="1150482003078" ID="Freemind_Link_185758115" MODIFIED="1150482010531" TEXT="text color"/>
<node CREATED="1150482015906" ID="Freemind_Link_549524723" MODIFIED="1150482019437" TEXT="AZ color"/>
<node CREATED="1150482020468" ID="Freemind_Link_1317150588" MODIFIED="1150482023984" TEXT="EQ color"/>
<node CREATED="1150482024703" ID="Freemind_Link_405579571" MODIFIED="1150482029984" TEXT="equator color"/>
<node CREATED="1150482030406" ID="Freemind_Link_100029781" MODIFIED="1150482034390" TEXT="ecliptic color"/>
<node CREATED="1150482034750" ID="Freemind_Link_400201748" MODIFIED="1150482038609" TEXT="meridian color"/>
<node CREATED="1150482039031" ID="Freemind_Link_140050500" MODIFIED="1150482047203" TEXT="const. lines color"/>
<node CREATED="1150482047718" ID="Freemind_Link_46467035" MODIFIED="1150482053062" TEXT="const. names color"/>
<node CREATED="1150482053453" ID="Freemind_Link_5204143" MODIFIED="1150482065843" TEXT="const. boundary color"/>
<node CREATED="1150482066265" ID="Freemind_Link_635287979" MODIFIED="1150482077531" TEXT="nebula label color"/>
<node CREATED="1150482077843" ID="Freemind_Link_967781920" MODIFIED="1150482086984" TEXT="nebula circle color"/>
<node CREATED="1150482087906" ID="Freemind_Link_19182393" MODIFIED="1150482092828" TEXT="star label color"/>
<node CREATED="1150482093109" ID="Freemind_Link_1687021286" MODIFIED="1150482099015" TEXT="star circle color"/>
<node CREATED="1150482099281" ID="Freemind_Link_1855110112" MODIFIED="1150482104156" TEXT="cardinal color"/>
<node CREATED="1150482105031" ID="Freemind_Link_72597997" MODIFIED="1150482109000" TEXT="planet names color"/>
<node CREATED="1150482110031" ID="Freemind_Link_1091840622" MODIFIED="1150482116468" TEXT="planet orbits color"/>
<node CREATED="1150482117609" ID="Freemind_Link_1792045163" MODIFIED="1150482124375" TEXT="object trails color"/>
<node CREATED="1150482124625" ID="Freemind_Link_272079305" MODIFIED="1150482128015" TEXT="chart color"/>
</node>
<node CREATED="1150481956859" FOLDED="true" ID="Freemind_Link_1800090401" MODIFIED="1202856263635" TEXT="standard colors" VSHIFT="2">
<node CREATED="1150481968859" ID="Freemind_Link_286752508" MODIFIED="1150482013546" TEXT="base color"/>
<node CREATED="1150482003078" ID="Freemind_Link_1679066210" MODIFIED="1150482010531" TEXT="text color"/>
<node CREATED="1150482015906" ID="Freemind_Link_133343682" MODIFIED="1150482019437" TEXT="AZ color"/>
<node CREATED="1150482020468" ID="Freemind_Link_395561314" MODIFIED="1150482023984" TEXT="EQ color"/>
<node CREATED="1150482024703" ID="Freemind_Link_831465240" MODIFIED="1150482029984" TEXT="equator color"/>
<node CREATED="1150482030406" ID="Freemind_Link_424885496" MODIFIED="1150482034390" TEXT="ecliptic color"/>
<node CREATED="1150482034750" ID="Freemind_Link_212255083" MODIFIED="1150482038609" TEXT="meridian color"/>
<node CREATED="1150482039031" ID="Freemind_Link_789793878" MODIFIED="1150482047203" TEXT="const. lines color"/>
<node CREATED="1150482047718" ID="Freemind_Link_1270631575" MODIFIED="1150482053062" TEXT="const. names color"/>
<node CREATED="1150482053453" ID="Freemind_Link_792953455" MODIFIED="1150482065843" TEXT="const. boundary color"/>
<node CREATED="1150482066265" ID="Freemind_Link_1422111384" MODIFIED="1150482077531" TEXT="nebula label color"/>
<node CREATED="1150482077843" ID="Freemind_Link_469422177" MODIFIED="1150482086984" TEXT="nebula circle color"/>
<node CREATED="1150482087906" ID="Freemind_Link_254007687" MODIFIED="1150482092828" TEXT="star label color"/>
<node CREATED="1150482093109" ID="Freemind_Link_914324738" MODIFIED="1150482099015" TEXT="star circle color"/>
<node CREATED="1150482099281" ID="Freemind_Link_1476388204" MODIFIED="1150482104156" TEXT="cardinal color"/>
<node CREATED="1150482105031" ID="Freemind_Link_678553025" MODIFIED="1150482109000" TEXT="planet names color"/>
<node CREATED="1150482110031" ID="Freemind_Link_902530573" MODIFIED="1150482116468" TEXT="planet orbits color"/>
<node CREATED="1150482117609" ID="Freemind_Link_1385981999" MODIFIED="1150482124375" TEXT="object trails color"/>
<node CREATED="1150482124625" ID="Freemind_Link_269416319" MODIFIED="1150482128015" TEXT="chart color"/>
</node>
<node CREATED="1150486591250" FOLDED="true" HGAP="27" ID="Freemind_Link_1086401867" MODIFIED="1150486741609" TEXT="font">
<node CREATED="1150481750734" ID="Freemind_Link_250164239" MODIFIED="1150481755203" TEXT="font size"/>
<node CREATED="1150481795171" ID="Freemind_Link_730856295" MODIFIED="1150481799937" TEXT="font file"/>
</node>
</node>
</node>
<node CREATED="1202856001909" ID="Freemind_Link_1530875491" MODIFIED="1202857103273" TEXT="planetarium">
<node CREATED="1202856083043" FOLDED="true" ID="Freemind_Link_277253978" MODIFIED="1202856122579" TEXT="spherical mirror">
<node CREATED="1150482931265" FOLDED="true" ID="Freemind_Link_1643056585" MODIFIED="1202856153726" TEXT="mirror parameters" VSHIFT="-5">
<node CREATED="1150482956046" ID="Freemind_Link_1239363056" MODIFIED="1150482960687" TEXT="projector gamma"/>
<node CREATED="1150482962359" ID="Freemind_Link_1515182942" MODIFIED="1150482969187" TEXT="projector x position"/>
<node CREATED="1150482969468" ID="Freemind_Link_1306117006" MODIFIED="1150482975109" TEXT="projector y position"/>
<node CREATED="1150482976734" ID="Freemind_Link_1791992821" MODIFIED="1150482982734" TEXT="projector z position"/>
<node CREATED="1150482984234" ID="Freemind_Link_1660193245" MODIFIED="1150482994546" TEXT="mirror x position"/>
<node CREATED="1150482994906" ID="Freemind_Link_1840839669" MODIFIED="1150482999046" TEXT="mirror y position"/>
<node CREATED="1150482999312" ID="Freemind_Link_1050391481" MODIFIED="1150483003281" TEXT="mirror z position"/>
<node CREATED="1150483004218" ID="Freemind_Link_744199247" MODIFIED="1150483007687" TEXT="mirror radius"/>
<node CREATED="1150483009218" ID="Freemind_Link_1897175816" MODIFIED="1150483011343" TEXT="dome radius"/>
<node CREATED="1150483011765" ID="Freemind_Link_1021648056" MODIFIED="1150483018390" TEXT="zenith y"/>
<node CREATED="1150483018640" ID="Freemind_Link_388555779" MODIFIED="1150483022703" TEXT="scaling factor"/>
</node>
<node CREATED="1202856143019" ID="Freemind_Link_1857449655" MODIFIED="1202856146519" TEXT="activate"/>
</node>
<node CREATED="1150487294546" FOLDED="true" HGAP="28" ID="Freemind_Link_657996494" MODIFIED="1150487597703" TEXT="TUI options" VSHIFT="-4">
<node CREATED="1150487323781" ID="Freemind_Link_1487215697" MODIFIED="1150487326484" TEXT="show TUI"/>
<node CREATED="1150487331578" ID="Freemind_Link_263755255" MODIFIED="1150487335468" TEXT="gravity TUI"/>
<node CREATED="1150487344078" ID="Freemind_Link_552917786" MODIFIED="1150487348921" TEXT="show date and time in TUI"/>
<node CREATED="1150487355234" ID="Freemind_Link_1315957229" MODIFIED="1150487365343" TEXT="show short object info in TUI"/>
</node>
<node CREATED="1150483534968" ID="Freemind_Link_757277733" MODIFIED="1150483543000" TEXT="gravity labels"/>
<node CREATED="1150484750687" ID="Freemind_Link_844362930" MODIFIED="1150484754796" TEXT="disc viewport"/>
<node CREATED="1190404972921" ID="Freemind_Link_963843025" MODIFIED="1190404976125" TEXT="sky language"/>
</node>
<node CREATED="1202853671886" ID="Freemind_Link_1987145465" MODIFIED="1202857115653" STYLE="fork" TEXT="amateur astronomer tools" VSHIFT="6">
<cloud/>
<node CREATED="1150481385281" FOLDED="true" ID="Freemind_Link_882075950" MODIFIED="1202855755737" TEXT="telescopes management" VSHIFT="1">
<cloud/>
<node CREATED="1150485648468" ID="Freemind_Link_1719502300" MODIFIED="1150485655828" TEXT="telescope goto"/>
<node CREATED="1150485657671" ID="Freemind_Link_1224894730" MODIFIED="1150485659984" TEXT="status"/>
<node CREATED="1202854369108" ID="Freemind_Link_411524457" MODIFIED="1202854379248" TEXT="telescope server control"/>
</node>
<node CREATED="1150487663937" ID="Freemind_Link_110718623" MODIFIED="1202856944119" TEXT="show image flip controls" VSHIFT="-7"/>
<node CREATED="1202854506626" FOLDED="true" ID="Freemind_Link_1168478955" MODIFIED="1202854576741" TEXT="occulars management">
<node CREATED="1202855180109" ID="Freemind_Link_444624157" MODIFIED="1202855201099" TEXT="occular list"/>
<node CREATED="1202855216844" ID="Freemind_Link_1171424144" MODIFIED="1202855227009" TEXT="add new occular"/>
</node>
<node CREATED="1150486017062" ID="Freemind_Link_1861025500" MODIFIED="1202854561581" TEXT="night view mode"/>
<node CREATED="1150486020140" HGAP="23" ID="Freemind_Link_223731728" MODIFIED="1202854591548" TEXT="chart view mode" VSHIFT="-18"/>
<node CREATED="1202854756910" HGAP="23" ID="Freemind_Link_1630778095" MODIFIED="1202855019339" TEXT="show sidereal time" VSHIFT="-28"/>
</node>
<node CREATED="1190407499812" HGAP="21" ID="Freemind_Link_1348197327" MODIFIED="1202859322907" TEXT="plugins management" VSHIFT="8"/>
</node>
</node>
<node CREATED="1202858347096" HGAP="74" ID="Freemind_Link_1690075164" MODIFIED="1202859648310" POSITION="left" TEXT="windows toggle bar" VSHIFT="-204">
<cloud/>
<node CREATED="1202858396002" ID="Freemind_Link_1569702491" MODIFIED="1202858399447" TEXT="time"/>
<node CREATED="1202858402937" ID="Freemind_Link_1261272895" MODIFIED="1202858405901" TEXT="location"/>
<node CREATED="1202858438329" ID="Freemind_Link_1605807592" MODIFIED="1202858442128" TEXT="view"/>
<node CREATED="1202858444608" ID="Freemind_Link_964585010" MODIFIED="1202858448270" TEXT="starlore"/>
<node CREATED="1202859017379" ID="Freemind_Link_1322410644" MODIFIED="1202859022450" TEXT="search"/>
<node CREATED="1202859023714" ID="Freemind_Link_1792690330" MODIFIED="1202859027326" TEXT="help"/>
<node CREATED="1202859028431" ID="Freemind_Link_1509112819" MODIFIED="1202859039754" TEXT="script"/>
<node CREATED="1202859042580" ID="Freemind_Link_1426165401" MODIFIED="1202859049455" TEXT="program options"/>
</node>
</node>
</map>
